pygeodesy.fstats._FstatsNamed

Package pygeodesy :: Module fstats :: Class _FstatsNamed |
[frames] | no frames]

# Class _FstatsNamed

      object --+
               |
    named._Named --+
                   |
                  _FstatsNamed

Known Subclasses:
  - _FstatsBase
  - , Flinear

(INTERNAL) Base class.

Instance Methods
__add__(self, other) Sum of this and an other instance, a `scalar`, an Fsum or Fsum2Tuple. |
__float__(self) Not implemented. |
__int__(self) Not implemented. |
__len__(self) Return the total number of accumulated `Scalars` (`int`). |
__neg__(self) Not implemented. |
__radd__(self, other) Not implemented. |
__str__(self) Default `str(self)`. |
copy(self, deep=False, **name) Copy this instance, `shallow` or `deep`. |
fcopy(self, deep=False, **name) Copy this instance, `shallow` or `deep`. |
Inherited from `named._Named`: `__format__`, `__imatmul__`, `__matmul__`, `__repr__`, `__rmatmul__`, `attrs`, `classof`, `dup`, `methodname`, `rename`, `renamed`, `toRepr`, `toStr`, `toStr2` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__init__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties
Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### __str__ (self) (Informal representation operator) |
Default `str(self)`. Overrides: object.__str__ (inherited documentation)

### copy (self, deep=False, **name) |
Copy this instance, `shallow` or `deep`. Arguments: `name` - Optional, overriding `name="copy"` (`str`). Returns: The copy instance. Overrides: named._Named.copy

### fcopy (self, deep=False, **name) |
Copy this instance, `shallow` or `deep`. Arguments: `name` - Optional, overriding `name="copy"` (`str`). Returns: The copy instance.